var indexSectionsWithContent =
{
  0: "abcdefghijmnoprstuvwxyz~",
  1: "biopt",
  2: "p",
  3: "bp",
  4: "abcdefgijmnoprstvwz~",
  5: "abcdefhimnoprstuvwxyz",
  6: "p"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Pages"
};

